@@ -33,10 +33,15 @@ def ppp(*args):
 
 
 # ----- Syntax & allowed extensions -----
-syntax = st.radio("Program syntax", ["natlog", "prolog"], horizontal=True)
 # Expected ext with and without dot
-expected_ext_no_dot = "nat" if syntax == "natlog" else "pro"
-expected_ext_dot = f".{expected_ext_no_dot}"
+expected_ext_no_dot = ["nat", "pro", "pl"]
+
+# ext = "nat"  # by default, allows just query the lib
+
+
+def syntax():  # ext is extension
+    assert ext in expected_ext_no_dot, expected_ext_no_dot
+    return "natlog" if ext == "nat" else "prolog"
 
 
 # ----- Helpers -----
@@ -76,19 +81,18 @@ def load_file_text(path_str: str) -> str:
 
 # ----- Upload UI -----
 uploaded = st.sidebar.file_uploader(
-    "Select a file",
-    type=[expected_ext_no_dot],  # must be extension without dot
+    "Select a file", type=expected_ext_no_dot  # must be extension without dot
 )
 
 # If a new file is uploaded this run, validate & save it.
-if uploaded is not None:
-    # Double-check extension (defensive; streamlit already filters by 'type=')
+if uploaded is not None:  # ext will be defined
     _, ext = os.path.splitext(uploaded.name)
-    if ext.lower() != expected_ext_dot:
-        st.sidebar.error(
-            f"Please choose a {expected_ext_dot} file to match '{syntax}' syntax."
-        )
-    else:
+    if ext.startswith("."):
+        ext = ext[1:]
+    print("!!! UPLOADED:", ext)
+    if ext.lower() not in expected_ext_no_dot:
+        st.sidebar.error(f"Please choose a file with suffix in {expected_ext_no_dot}!")
+    else:  # ext is good
         try:
             saved_path, text = save_uploaded_file(uploaded)
             st.session_state.uploaded_path = saved_path
@@ -96,6 +100,9 @@ if uploaded is not None:
             st.sidebar.success(f"Saved to {saved_path}")
         except Exception as ex:
             st.sidebar.error(f"Saving failed: {ex}")
+else:
+    ext = "nat"  # default
+
 
 # Convenience: show current file info
 if st.session_state.uploaded_path:
@@ -106,7 +113,12 @@ if st.session_state.uploaded_path:
 if st.session_state.uploaded_path and not st.session_state.program_text:
     st.session_state.program_text = load_file_text(st.session_state.uploaded_path)
 
+if uploaded is None:
+    editor_syntax = st.radio("Editor syntax", ["natlog", "prolog"], horizontal=True)
+
 editor = st.text_area("Program text:", st.session_state.program_text, height=320)
+if not editor:
+    editor = "hello."
 
 # Allow saving edits back to the same file (optional but handy)
 col_save, col_clear = st.columns([1, 1])
@@ -128,9 +140,11 @@ with col_clear:
         st.session_state.uploaded_path = None
 
 # ----- Query UI -----
+
 with st.sidebar:
-    question = st.text_area("Query?")
-    query_it = st.button("Submit your question!")
+
+    question = st.text_area(f"Enter your {syntax()} query!")
+    query_it = st.button("Submit query!")
 
 
 def do_query():
@@ -139,11 +153,14 @@ def do_query():
         lib = natprogs() + "lib.nat"
         with_lib = None if st.session_state.uploaded_path == lib else lib
         nat = Natlog(
-            file_name=st.session_state.uploaded_path, syntax=syntax, with_lib=with_lib
+            file_name=st.session_state.uploaded_path,
+            syntax=syntax(),
+            with_lib=with_lib,
         )
     else:
-        print("running with code in editor, chars:", len(editor), "syntax:", syntax)
-        nat = Natlog(text=editor, syntax=syntax, with_lib=natprogs() + "lib.nat")
+        print("running with code in editor, chars:", len(editor))
+        print("syntax:", syntax())
+        nat = Natlog(text=editor, syntax=syntax(), with_lib=natprogs() + "lib.nat")
 
     ppp("?- " + question)
     success = False
